@@ -1,6 +1,6 @@
 /* gzip.h -- common declarations for all gzip modules
 
-   Copyright (C) 1997-1999, 2001, 2006-2007, 2009-2018 Free Software
+   Copyright (C) 1997-1999, 2001, 2006-2007, 2009-2025 Free Software
    Foundation, Inc.
 
    Copyright (C) 1992-1993 Jean-loup Gailly.
@@ -16,8 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifdef __STDC__
    typedef void *voidp;
@@ -38,11 +37,8 @@
 #include <sys/types.h> /* for off_t */
 #include <time.h>
 #include <string.h>
-#include <stdnoreturn.h>
 #define memzero(s, n) memset ((voidp)(s), 0, (n))
 
-#define local static
-
 typedef unsigned char  uch;
 typedef unsigned short ush;
 typedef unsigned long  ulg;
@@ -77,7 +73,7 @@ extern int method;         /* compression method */
 #  ifdef SMALL_MEM
 #    define INBUFSIZ  0x2000  /* input buffer size */
 #  else
-#    define INBUFSIZ  0x8000  /* input buffer size */
+#    define INBUFSIZ  0x40000 /* input buffer size */
 #  endif
 #endif
 #define INBUF_EXTRA  64     /* required by unlzw() */
@@ -86,7 +82,7 @@ extern int method;         /* compression method */
 #  ifdef SMALL_MEM
 #    define OUTBUFSIZ   8192  /* output buffer size */
 #  else
-#    define OUTBUFSIZ  16384  /* output buffer size */
+#    define OUTBUFSIZ 0x40000 /* output buffer size */
 #  endif
 #endif
 #define OUTBUF_EXTRA 2048   /* required by unlzw() */
@@ -191,7 +187,6 @@ typedef int file_t;     /* Do not use stdio */
  */
 
 extern int exit_code;      /* program exit code */
-extern int verbose;        /* be verbose (-v) */
 extern int quiet;          /* be quiet (-q) */
 extern int level;          /* compression level */
 extern int test;           /* check .z file integrity */
@@ -239,6 +234,7 @@ extern int save_orig_name; /* set if original name must be saved */
 
 /* Diagnostic functions */
 #ifdef DEBUG
+extern int verbose;        /* be verbose (-v) */
 #  define Assert(cond,msg) {if (!(cond)) gzip_error (msg);}
 #  define Trace(x) fprintf x
 #  define Tracev(x) {if (verbose) fprintf x ;}
@@ -254,14 +250,22 @@ extern int save_orig_name; /* set if original name must be saved */
 #  define Tracecv(c,x)
 #endif
 
-#define WARN(msg) {if (!quiet) fprintf msg ; \
-                   if (exit_code == OK) exit_code = WARNING;}
+#define WARN(msg) \
+  do \
+    { \
+      if (!quiet) \
+        fprintf msg; \
+      if (exit_code == OK) \
+        exit_code = WARNING; \
+    } \
+  while (false)
 
         /* in zip.c: */
 extern int zip        (int in, int out);
 extern int file_read  (char *buf,  unsigned size);
 
         /* in unzip.c */
+extern ulg unzip_crc;
 extern int unzip      (int in, int out);
 extern int check_zipfile (int in);
 
@@ -272,11 +276,11 @@ extern int unpack     (int in, int out);
 extern int unlzh      (int in, int out);
 
         /* in gzip.c */
-extern noreturn void abort_gzip (void);
+_Noreturn extern void finish_up_gzip (int);
+_Noreturn extern void abort_gzip (void);
 
         /* in deflate.c */
-extern void lm_init (int pack_level, ush *flags);
-extern off_t deflate (void);
+extern off_t gzip_deflate (int pack_level);
 
         /* in trees.c */
 extern void ct_init     (ush *attr, int *method);
@@ -284,6 +288,10 @@ extern int  ct_tally    (int dist, int lc);
 extern off_t flush_block (char *buf, ulg stored_len, int pad, int eof);
 
         /* in bits.c */
+#ifdef IBM_Z_DFLTCC
+extern unsigned short bi_buf;
+extern int bi_valid;
+#endif
 extern void     bi_init    (file_t zipfile);
 extern void     send_bits  (int value, int length);
 extern unsigned bi_reverse (unsigned value, int length) _GL_ATTRIBUTE_CONST;
@@ -293,7 +301,9 @@ extern int     (*read_buf) (char *buf, unsigned size);
 
         /* in util.c: */
 extern int copy           (int in, int out);
-extern ulg  updcrc        (uch *s, unsigned n);
+extern ulg  updcrc        (const uch *s, unsigned n);
+extern ulg  getcrc        (void) _GL_ATTRIBUTE_PURE;
+extern void setcrc        (ulg c);
 extern void clear_bufs    (void);
 extern int  fill_inbuf    (int eof_ok);
 extern void flush_outbuf  (void);
@@ -305,13 +315,18 @@ extern char *gzip_base_name (char *fname) _GL_ATTRIBUTE_PURE;
 extern int xunlink        (char *fname);
 extern void make_simple_name (char *name);
 extern char *add_envopt   (int *argcp, char ***argvp, char const *env);
-extern noreturn void gzip_error    (char const *m);
-extern noreturn void xalloc_die    (void);
+_Noreturn extern void gzip_error (char const *m);
+_Noreturn extern void xalloc_die (void);
 extern void warning       (char const *m);
-extern noreturn void read_error    (void);
-extern noreturn void write_error   (void);
+_Noreturn extern void read_error (void);
+_Noreturn extern void write_error (void);
 extern void display_ratio (off_t num, off_t den, FILE *file);
-extern void fprint_off    (FILE *, off_t, int);
 
         /* in inflate.c */
-extern int inflate (void);
+extern int gzip_inflate (void);
+
+        /* in dfltcc.c */
+#ifdef IBM_Z_DFLTCC
+extern int dfltcc_deflate (int pack_level);
+extern int dfltcc_inflate (void);
+#endif
