@@ -1,6 +1,6 @@
 /* Inflate deflated data
 
-   Copyright (C) 1997-1999, 2002, 2006, 2009-2018 Free Software Foundation,
+   Copyright (C) 1997-1999, 2002, 2006, 2009-2025 Free Software Foundation,
    Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Not copyrighted 1992 by Mark Adler
    version c10p1, 10 January 1993 */
@@ -46,7 +45,7 @@
    There are (currently) three kinds of inflate blocks: stored, fixed, and
    dynamic.  The compressor deals with some chunk of data at a time, and
    decides which method to use on a chunk-by-chunk basis.  A chunk might
-   typically be 32K or 64K.  If the chunk is uncompressible, then the
+   typically be 32K or 64K.  If the chunk is incompressible, then the
    "stored" method is used.  In this case, the bytes are simply stored as
    is, eight bits per byte, with none of the above coding.  The bytes are
    preceded by a count, since there is no longer an EOB code.
@@ -153,8 +152,9 @@ static int huft_free (struct huft *);
    "uch *slide;" and then malloc'ed in the latter case.  The definition
    must be in unzip.h, included above. */
 /* unsigned wp;             current position in slide */
+static bool fresh;
 #define wp outcnt
-#define flush_output(w) (wp=(w),flush_window())
+#define flush_output(w) (fresh = false, wp = (w), flush_window ())
 
 /* Tables for deflate from PKZIP's appnote.txt. */
 static unsigned border[] = {    /* Order of the bit length code lengths */
@@ -177,7 +177,7 @@ static ush cpdext[] = {         /* Extra bits for distance codes */
 
 
 
-/* Macros for inflate() bit peeking and grabbing.
+/* Macros for gzip_inflate () bit peeking and grabbing.
    The usage is:
 
         NEEDBITS(j)
@@ -310,8 +310,18 @@ int *m                  /* maximum lookup bits, returns actual */
   memzero(c, sizeof(c));
   p = b;  i = n;
   do {
-    Tracecv(*p, (stderr, (n-i >= ' ' && n-i <= '~' ? "%c %d\n" : "0x%x %d\n"),
-            n-i, *p));
+#ifdef DEBUG
+    if (1 < verbose && *p)
+      {
+        if (' ' <= n - i && n - i <= '~')
+          {
+            char ch = n - i;
+            fprintf (stderr, "%c %u\n", ch, *p);
+          }
+        else
+          fprintf (stderr, "0x%x %u\n", n - i, *p);
+      }
+#endif
     c[*p]++;                    /* assume all entries <= BMAX */
     p++;                      /* Can't combine with above line (Solaris bug) */
   } while (--i);
@@ -503,7 +513,7 @@ huft_free(struct huft *t)
 
 /* tl, td:   literal/length and distance decoder tables */
 /* bl, bd:   number of bits decoded by tl[] and td[] */
-/* inflate (decompress) the codes in a deflated (compressed) block.
+/* gzip_inflate (decompress) the codes in a deflated (compressed) block.
    Return an error code or zero if it all goes ok. */
 static int
 inflate_codes(struct huft *tl, struct huft *td, int bl, int bd)
@@ -572,7 +582,9 @@ inflate_codes(struct huft *tl, struct huft *td, int bl, int bd)
       NEEDBITS(e)
       d = w - t->v.n - ((unsigned)b & mask_bits[e]);
       DUMPBITS(e)
-      Tracevv((stderr,"\\[%d,%d]", w-d, n));
+      if (fresh && w <= d)
+        return 1;
+      Tracevv ((stderr, "\\[%u,%u]", w - d, n));
 
       /* do the copy */
       do {
@@ -942,7 +954,7 @@ static int inflate_block(int *e)
 
 
 int
-inflate(void)
+gzip_inflate ()
 /* decompress an inflated entry */
 {
   int e;                /* last block flag */
@@ -954,6 +966,7 @@ inflate(void)
   wp = 0;
   bk = 0;
   bb = 0;
+  fresh = true;
 
 
   /* decompress until the last block */
